@@ -1,9 +1,8 @@
 library(testthat)
 
-skip_on_cran()
-
-source("tensor_functions.R")
+source("helper_utils.R")
 
+skip_if_no_torch()
 
 # matrix like tensor operations ------------------------------------------------
 context("matrix like tensor operations")
